The Moco Instance
===================

.. autoclass:: moco_wrapper.Moco
   :inherited-members:

.. _moco_instance_endpoints:
.. toctree::
   :maxdepth: 1
   :caption: API Endpoints

   endpoints/activity
   endpoints/comment
   endpoints/company
   endpoints/contact
   endpoints/deal
   endpoints/deal_category
   endpoints/hourly_rate
   endpoints/invoice
   endpoints/invoice_payment
   endpoints/offer
   endpoints/project
   endpoints/project_contract
   endpoints/project_expense
   endpoints/project_recurring_expense
   endpoints/project_payment_schedule
   endpoints/project_task
   endpoints/planning_entry
   endpoints/purchase
   endpoints/purchase_category
   endpoints/schedule
   endpoints/tagging
   endpoints/unit
   endpoints/user
   endpoints/user_employment
   endpoints/user_holiday
   endpoints/user_presence
   endpoints/session

